Structs
- CfsPacket
- Resolved cFS packet facts for registry-style validation.
- Rust
Options - Options for Rust cFS binding generation.
Enums
- CfsPacket
Kind - cFS packet category used by mission-wide validation.
- Codegen
Error - Error returned when a parsed Synapse file cannot be emitted safely.
Constants
- GENERATED_
BANNER - Deterministic banner included at the top of generated files.
- PREAMBLE
- Preamble included at the top of generated cFS C headers.
Functions
- collect_
cfs_ packets_ with_ constants - Collect resolved cFS packet facts with additional imported constants available.
- generate_
c - Generate a NASA cFS C header from a parsed Synapse file.
- generate_
rust - Generate
#[repr(C)]Rust structs compatible with NASA cFS bindings. - resolve_
integer_ constants - Resolve this file’s integer constants, including aliases to visible imported constants.
- try_
generate_ c - Try to generate a NASA cFS C header from a parsed Synapse file.
- try_
generate_ c_ with_ constants - Try to generate a C header with additional imported constants available for attributes.
- try_
generate_ rust - Try to generate
#[repr(C)]Rust structs compatible with NASA cFS bindings. - try_
generate_ rust_ with_ constants - Try to generate Rust bindings with additional imported constants available for attributes.
- validate_
cfs - Validate that a parsed Synapse file is supported by cFS code generation.
- validate_
cfs_ with_ constants - Validate cFS code generation support with additional imported constants available.
Type Aliases
- Resolved
Constants - Resolved integer constants visible to a file from imported namespaces.