pub fn resolve_integer_constants(
file: &SynFile,
imported_constants: &ResolvedConstants,
) -> ResolvedConstantsExpand description
Resolve this file’s integer constants, including aliases to visible imported constants.
pub fn resolve_integer_constants(
file: &SynFile,
imported_constants: &ResolvedConstants,
) -> ResolvedConstantsResolve this file’s integer constants, including aliases to visible imported constants.