pub fn validate_cfs(file: &SynFile) -> Result<(), CodegenError>Expand description
Validate that a parsed Synapse file is supported by cFS code generation.
pub fn validate_cfs(file: &SynFile) -> Result<(), CodegenError>Validate that a parsed Synapse file is supported by cFS code generation.