pub fn validate_cfs_with_options(
file: &SynFile,
options: &CfsOptions,
) -> Result<(), CodegenError>Expand description
Validate that a parsed Synapse file is supported by cFS code generation.
pub fn validate_cfs_with_options(
file: &SynFile,
options: &CfsOptions,
) -> Result<(), CodegenError>Validate that a parsed Synapse file is supported by cFS code generation.