Structs
- CfsOptions
- Options for cFS validation and code generation.
- CfsPacket
- Resolved cFS packet facts for registry-style validation.
- Rust
Options - Options for Rust cFS binding generation.
Enums
- CfsPacket
Kind - cFS packet category used by mission-wide validation.
- Codegen
Error - Error returned when a parsed Synapse file cannot be emitted safely.
- MsgId
Layout - cFE message ID layout policy used for command/telemetry validation.
Constants
- GENERATED_
BANNER - Deterministic banner included at the top of generated files.
- PREAMBLE
- Preamble included at the top of generated cFS C headers.
Functions
- collect_
cfs_ packets_ with_ constants - Collect resolved cFS packet facts with additional imported constants available.
- collect_
cfs_ packets_ with_ constants_ and_ options - Collect resolved cFS packet facts with imported constants and options.
- generate_
c - Generate a NASA cFS C header (
*_msg.h+ MID#defines) from a parsed Synapse file. - generate_
rust - Generate
#[repr(C)]Rust structs compatible with NASA cFS bindings. - resolve_
integer_ constants - Resolve this file’s integer constants, including aliases to visible imported constants.
- try_
generate_ c - Try to generate a NASA cFS C header (
*_msg.h+ MID#defines`) from a parsed Synapse file. - try_
generate_ c_ with_ constants - Try to generate a C header with additional imported constants available for attributes.
- try_
generate_ c_ with_ constants_ and_ options - Try to generate a C header with imported constants and validation options.
- try_
generate_ c_ with_ options - Try to generate a NASA cFS C header with validation options.
- try_
generate_ rust - Try to generate
#[repr(C)]Rust structs compatible with NASA cFS bindings. - try_
generate_ rust_ with_ constants - Try to generate Rust bindings with additional imported constants available for attributes.
- try_
generate_ rust_ with_ constants_ and_ options - Try to generate Rust bindings with imported constants and validation options.
- try_
generate_ rust_ with_ options - Try to generate Rust bindings with validation options.
- validate_
cfs - Validate that a parsed Synapse file is supported by cFS code generation.
- validate_
cfs_ with_ constants - Validate cFS code generation support with additional imported constants available.
- validate_
cfs_ with_ constants_ and_ options - Validate cFS code generation support with imported constants and options.
- validate_
cfs_ with_ options - Validate that a parsed Synapse file is supported by cFS code generation.
Type Aliases
- Resolved
Constants - Resolved integer constants visible to a file from imported namespaces.