Crate synapse_codegen_cfs

Crate synapse_codegen_cfs 

Structs

CfsPacket
Resolved cFS packet facts for registry-style validation.
RustOptions
Options for Rust cFS binding generation.

Enums

CfsPacketKind
cFS packet category used by mission-wide validation.
CodegenError
Error returned when a parsed Synapse file cannot be emitted safely.

Constants

GENERATED_BANNER
Deterministic banner included at the top of generated files.
PREAMBLE
Preamble included at the top of generated cFS C headers.

Functions

collect_cfs_packets_with_constants
Collect resolved cFS packet facts with additional imported constants available.
generate_c
Generate a NASA cFS C header (*_msg.h + MID #defines) from a parsed Synapse file.
generate_rust
Generate #[repr(C)] Rust structs compatible with NASA cFS bindings.
resolve_integer_constants
Resolve this file’s integer constants, including aliases to visible imported constants.
try_generate_c
Try to generate a NASA cFS C header (*_msg.h + MID #defines`) from a parsed Synapse file.
try_generate_c_with_constants
Try to generate a C header with additional imported constants available for attributes.
try_generate_rust
Try to generate #[repr(C)] Rust structs compatible with NASA cFS bindings.
try_generate_rust_with_constants
Try to generate Rust bindings with additional imported constants available for attributes.
validate_cfs
Validate that a parsed Synapse file is supported by cFS code generation.
validate_cfs_with_constants
Validate cFS code generation support with additional imported constants available.

Type Aliases

ResolvedConstants
Resolved integer constants visible to a file from imported namespaces.