Crate synapse_codegen_cfs

Crate synapse_codegen_cfs 

Structs

RustOptions
Options for Rust cFS binding generation.

Enums

CodegenError
Error returned when a parsed Synapse file cannot be emitted safely.

Constants

GENERATED_BANNER
Deterministic banner included at the top of generated files.
PREAMBLE
Preamble included at the top of generated cFS C headers.

Functions

generate_c
Generate a NASA cFS C header (*_msg.h + MID #defines) from a parsed Synapse file.
generate_rust
Generate #[repr(C)] Rust structs compatible with NASA cFS bindings.
resolve_integer_constants
Resolve this file’s integer constants, including aliases to visible imported constants.
try_generate_c
Try to generate a NASA cFS C header (*_msg.h + MID #defines`) from a parsed Synapse file.
try_generate_c_with_constants
Try to generate a C header with additional imported constants available for attributes.
try_generate_rust
Try to generate #[repr(C)] Rust structs compatible with NASA cFS bindings.
try_generate_rust_with_constants
Try to generate Rust bindings with additional imported constants available for attributes.

Type Aliases

ResolvedConstants
Resolved integer constants visible to a file from imported namespaces.